/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: PersonnalInfoSender.java 3078 2009-10-01 10:24:29Z porcherg $
 * --------------------------------------------------------------------------
 */

package org.ow2.orchestra.izpack.infosender;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Properties;

import org.apache.log4j.ConsoleAppender;
import org.apache.log4j.FileAppender;
import org.apache.log4j.Level;
import org.apache.log4j.Logger;
import org.apache.log4j.PatternLayout;
import org.apache.log4j.varia.LevelMatchFilter;
import org.ow2.util.geolocation.client.GeoClient;


/**
 * This class send user informations to the stat service.
 *
 * @author mathieu ancelin
 *
 */
public class PersonnalInfoSender {

    /**
     * The logger of the class for traces.
     */
    private static final Logger LOG = Logger
            .getLogger(PersonnalInfoSender.class.getName());
    /**
     * The ezb.properties object.
     */
    private Properties orchestraProperties = null;

    /**
     * The FileInputStream to read the properties file.
     */
    private FileInputStream readProperties = null;

    /**
     * The constructor of the class. Just send the informations on the stat
     * service.
     *
     * @param path
     *            the install path of orchestra
     */
    public PersonnalInfoSender(final String path) {

        try {
            this.orchestraProperties = this.openPropertiesFile(path + "orchestra.properties");
        } catch (final Exception e) {
            PersonnalInfoSender.LOG.log(Level.INFO,
                    "Error while reading properties file at " + path
                            + "orchestra.properties");
            PersonnalInfoSender.LOG.log(Level.ERROR, e);
            System.exit(-1);
        }
        final GeoClient client = new GeoClient("Orchestra",
            (String) this.orchestraProperties.get("version"),
            (String) this.orchestraProperties.get("email"),
            (String) this.orchestraProperties.get("proxyaddress"),
            (String) this.orchestraProperties.get("proxyport"),
            (String) this.orchestraProperties.get("proxyuser"),
            (String) this.orchestraProperties.get("proxypwd"));
        client.start();
    }

    /**
     * This method is used to open a propertie file and load it into a
     * properties object resource.
     *
     * @param path
     *            the path of the properties file to load.
     * @return the Properties Object.
     */
    public synchronized Properties openPropertiesFile(final String path) {
        final Properties tmp = new Properties();
        try {
            this.readProperties = new FileInputStream(path);
            tmp.load(this.readProperties);
        } catch (final FileNotFoundException e) {
            PersonnalInfoSender.LOG.log(Level.ERROR, e);
        } catch (final IOException e) {
            PersonnalInfoSender.LOG.log(Level.ERROR, e);
        }
        return tmp;
    }

    /**
     * Main method of the program.
     *
     * @param args
     *            the command line arguments.
     */
    public static void main(final String[] args) {
        /**
         * Configuration of log4j loggers. The console appender only displays
         * INFO traces
         */
        final PatternLayout layout = new PatternLayout("%d %p - %F:%L - %m%n");
        final PatternLayout layoutconsole = new PatternLayout("%m%n");
        final ConsoleAppender stdout = new ConsoleAppender(layoutconsole);
        final LevelMatchFilter filterError = new LevelMatchFilter();
        final LevelMatchFilter filterDebug = new LevelMatchFilter();
        final LevelMatchFilter filterFatal = new LevelMatchFilter();
        filterError.setLevelToMatch("ERROR");
        filterDebug.setLevelToMatch("DEBUG");
        filterFatal.setLevelToMatch("FATAL");
        filterError.setAcceptOnMatch(false);
        filterDebug.setAcceptOnMatch(false);
        filterFatal.setAcceptOnMatch(false);
        stdout.addFilter(filterDebug);
        stdout.addFilter(filterError);
        stdout.addFilter(filterFatal);
        FileAppender fileout;
        try {
            if (args.length != 0) {
                /**
                 * Create log files in the installation path
                 */
                fileout = new FileAppender(layout, args[0]
                        + "installationnotifier.log");
            } else {
                fileout = new FileAppender(layout, "sender.log");
            }
            PersonnalInfoSender.LOG.addAppender(fileout);
            PersonnalInfoSender.LOG.addAppender(stdout);
        } catch (final IOException e) {
            e.printStackTrace();
        }
        /**
         * Checking if argument are present
         */
        if (args.length < 1) {
            PersonnalInfoSender.LOG.log(Level.ERROR, "Bad argument at launching time");
            System.exit(-1);
        } else {
            new PersonnalInfoSender(args[0]);
        }
    }
}
